/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DBObject.java 511426 2007-02-25 03:25:02Z vgritsenko $
 */

package org.apache.xindice.core;

/**
 * DBObject is the interface implemented by all Xindice database objects.
 * DBObjects are typically objects that can be managed using XML
 * configuration information, which is typically stored in the system
 * database.  XMLObjects are not considered DBObjects because of the
 * steps involved in having to generate them, which is usually
 * compilation of source code.
 *
 * @version $Revision: 511426 $, $Date: 2007-02-24 22:25:02 -0500 (Sat, 24 Feb 2007) $
 */
public interface DBObject {

    /**
     * create creates a new DBObject and any associated resources for the new
     * DBObject, such as disk files, etc.
     *
     * @return Whether or not the DBObject was created
     */
    boolean create() throws DBException;

    /**
     * open opens the DBObject
     *
     * @return Whether or not the DBObject was opened
     */
    boolean open() throws DBException;

    /**
     * isOpened returns whether or not the DBObject is opened for business.
     *
     * @return The open status of the DBObject
     */
    boolean isOpened() throws DBException;

    /**
     * exists returns whether or not a physical representation of this
     * DBObject actually exists.  In the case of a HashFiler, this would
     * check for the file, and in the case of an FTPFiler, it might
     * perform a connection check.
     *
     * @return Whether or not the physical resource exists
     */
    boolean exists() throws DBException;

    /**
     * drop instructs the DBObjectimplementation to remove itself from
     * existence.  The DBObject's parent is responsible for removing any
     * references to the DBObject in its own context.
     *
     * @return Whether or not the DBObject was dropped
     */
    boolean drop() throws DBException;

    /**
     * close closes the DBObject
     *
     * @return Whether or not the DBObject was closed
     */
    boolean close() throws DBException;
}
