/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: RPCMessageInterface.java 526028 2007-04-06 02:22:01Z vgritsenko $
 */

package org.apache.xindice.server.rpc;

import org.apache.xindice.core.DBException;
import org.apache.xindice.core.Collection;
import org.apache.xindice.core.FaultCodes;
import org.apache.xmlrpc.XmlRpcException;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.xmldb.api.base.ErrorCodes;
import org.xmldb.api.base.XMLDBException;

import java.util.Hashtable;

/**
 *
 * @version $Revision: 526028 $, $Date: 2007-04-05 22:22:01 -0400 (Thu, 05 Apr 2007) $
 */
public final class RPCMessageInterface {

    private static final Log log = LogFactory.getLog(Collection.class);

    public static final String MESSAGE_PARAM = "message";

    public Hashtable run(Hashtable message) throws Exception {
        // The method determines what class we load to handle the message.
        String type = (String)message.get(MESSAGE_PARAM);
        try {
            RPCMessage handler = (RPCMessage) Class.forName("org.apache.xindice.server.rpc.messages." + type).newInstance();
            return handler.execute(message);
        } catch (XMLDBException e) {
            if (log.isDebugEnabled()) {
                log.debug("Exception while processing XmlRpc command " + type, e);
            }

            throw new XmlRpcException(e.errorCode * FaultCodes.MAX_CODE + e.vendorErrorCode, e.getMessage());
        } catch (DBException e) {
            if (log.isDebugEnabled()) {
                log.debug("Exception while processing XmlRpc command " + type, e);
            }

            throw new XmlRpcException(ErrorCodes.VENDOR_ERROR * FaultCodes.MAX_CODE + e.faultCode, e.getMessage());
        } catch (Exception e) {
            if (log.isDebugEnabled()) {
                log.debug("Exception while processing XmlRpc command " + type, e);
            }

            throw e;
        }
    }
}
