/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Command.java 511426 2007-02-25 03:25:02Z vgritsenko $
 */

package org.apache.xindice.tools.command;

import java.util.Hashtable;

/**
 * Command is the standard interface command line arguments
 *
 * @version $Revision: 511426 $, $Date: 2007-02-24 22:25:02 -0500 (Sat, 24 Feb 2007) $
 */
public abstract class Command {

    // Collection manager path to instantiate
    public static final String XINDICEURI = "xindice://";
    public static final String XINDICELOCALURI = "xindice-embed://";
    public static final String XMLDBURI = "xmldb:";

    // Version of the XML:DB API that we are using
    public static final String XMLDBAPIVERSION = "1.0";

    // Class name of the Standard Xindice Indexer
    public static final String XINDICE_VAL_INDEXER = "org.apache.xindice.core.indexer.ValueIndexer";
    public static final String XINDICE_NAME_INDEXER = "org.apache.xindice.core.indexer.NameIndexer";

    //public boolean execute(Hashtable table, Database db)
    public abstract boolean execute(Hashtable table) throws Exception;

    // public class to return normalized CollectionURI for creation of a Collection object
    public String normalizeCollectionURI(String uri, String local) {
        // Check to see if this uri starts with "xmldb:" , if so treat as absolute
        if (uri.startsWith("xmldb:")) {
            // URI is absolute, leave alone
            return uri;
        } else if (uri.startsWith("xindice:") || uri.startsWith("xindice-embed:")) {
            return (XMLDBURI + uri);
        } else {
            if ((local != null) && local.equals("true")) {
                return (XMLDBURI + XINDICELOCALURI + uri);
            } else {
                // URI passed in is not absoulte, build the full URI
                return (XMLDBURI + XINDICEURI + uri);
            }
        }
    }
}
