/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: ListCollectionDocuments.java 511426 2007-02-25 03:25:02Z vgritsenko $
 */

package org.apache.xindice.tools.command;

import org.apache.xindice.tools.XMLTools;

import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;

import java.util.Hashtable;

/**
 * ListCollectionDocumets.java is designed to let the user list all documents in a specific collection.
 *
 * NOTE:  Document names are returned in no specific order
 *
 * @version $Revision: 511426 $, $Date: 2007-02-24 22:25:02 -0500 (Sat, 24 Feb 2007) $
 */
public class ListCollectionDocuments extends Command {

    public boolean execute(Hashtable table) throws Exception {

        Collection col = null;
        String colstring = null;
        String[] documentarray = null;
        try {

            if (table.get(XMLTools.COLLECTION) != null) {

                // Create a collection instance
                colstring = normalizeCollectionURI((String) table.get(XMLTools.COLLECTION),
                                                   (String) table.get(XMLTools.LOCAL));

                col = DatabaseManager.getCollection(colstring);
                if (col == null) {
                    System.out.println("ERROR : Collection not found!");
                    return false;
                }
                documentarray = col.listResources();

                System.out.println();

                for (int i = 0; i < documentarray.length; i++) {
                    System.out.println("\t" + documentarray[i]);
                }

                System.out.println("\nTotal documents: " + documentarray.length);
            } else
                System.out.println("ERROR : Collection and switch required");

        } finally {
            // Release the collection object
            if (col != null) {
                col.close();
            }
        }

        return true;
    }
}
