/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Shutdown.java 525295 2007-04-03 21:52:05Z vgritsenko $
 */

package org.apache.xindice.tools.command;

import org.apache.xindice.client.xmldb.services.DatabaseInstanceManager;
import org.apache.xindice.tools.XMLTools;

import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;

import java.util.Hashtable;

/**
 * Shutdown.java is designed to let the user shutdown
 * the Database.
 *
 * @version $Revision: 525295 $, $Date: 2007-04-03 17:52:05 -0400 (Tue, 03 Apr 2007) $
 */
public class Shutdown extends Command {

    //public boolean execute(Hashtable table, Database db)
    public boolean execute(Hashtable table) throws Exception {

        Collection col = null;
        if (table.get(XMLTools.COLLECTION) == null) {
            System.out.println("ERROR : Collection context required ");
            return false;
        }

        try {
            // Collection name can be incorrect, use database name instead
            String context = (String) table.get(XMLTools.COLLECTION);
            int i = context.indexOf('/', 1);
            String db;
            if (i >= 0) {
                db = context.substring(0, i);
            } else {
                db = context;
            }

            // Get a Collection reference to pass on to individual commands
            String colstring = normalizeCollectionURI(db, (String) table.get(XMLTools.LOCAL));
            col = DatabaseManager.getCollection(colstring);

            if (col != null) {
                DatabaseInstanceManager man = (DatabaseInstanceManager) col.getService("DatabaseInstanceManager", XMLDBAPIVERSION);

                // Shutdown the server
                man.shutdown();
            }
        } finally {
            if (col != null) {
                col.close();
            }
        }

        return true;
    }
}
